@@ -134,8 +134,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0591, 0x05c7},
 {0x05d0, 0x05ea},
 {0x05ef, 0x05f4},
-{0x0600, 0x061c},
-{0x061e, 0x070d},
+{0x0600, 0x070d},
 {0x070f, 0x074a},
 {0x074d, 0x07b1},
 {0x07c0, 0x07fa},
@@ -144,9 +143,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0840, 0x085b},
 {0x085e, 0x085e},
 {0x0860, 0x086a},
-{0x08a0, 0x08b4},
-{0x08b6, 0x08c7},
-{0x08d3, 0x0983},
+{0x0870, 0x088e},
+{0x0890, 0x0891},
+{0x0898, 0x0983},
 {0x0985, 0x098c},
 {0x098f, 0x0990},
 {0x0993, 0x09a8},
@@ -224,11 +223,12 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0c0e, 0x0c10},
 {0x0c12, 0x0c28},
 {0x0c2a, 0x0c39},
-{0x0c3d, 0x0c44},
+{0x0c3c, 0x0c44},
 {0x0c46, 0x0c48},
 {0x0c4a, 0x0c4d},
 {0x0c55, 0x0c56},
 {0x0c58, 0x0c5a},
+{0x0c5d, 0x0c5d},
 {0x0c60, 0x0c63},
 {0x0c66, 0x0c6f},
 {0x0c77, 0x0c8c},
@@ -240,10 +240,10 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0cc6, 0x0cc8},
 {0x0cca, 0x0ccd},
 {0x0cd5, 0x0cd6},
-{0x0cde, 0x0cde},
+{0x0cdd, 0x0cde},
 {0x0ce0, 0x0ce3},
 {0x0ce6, 0x0cef},
-{0x0cf1, 0x0cf2},
+{0x0cf1, 0x0cf3},
 {0x0d00, 0x0d0c},
 {0x0d0e, 0x0d10},
 {0x0d12, 0x0d44},
@@ -273,7 +273,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0ea7, 0x0ebd},
 {0x0ec0, 0x0ec4},
 {0x0ec6, 0x0ec6},
-{0x0ec8, 0x0ecd},
+{0x0ec8, 0x0ece},
 {0x0ed0, 0x0ed9},
 {0x0edc, 0x0edf},
 {0x0f00, 0x0f47},
@@ -309,9 +309,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x13f8, 0x13fd},
 {0x1400, 0x169c},
 {0x16a0, 0x16f8},
-{0x1700, 0x170c},
-{0x170e, 0x1714},
-{0x1720, 0x1736},
+{0x1700, 0x1715},
+{0x171f, 0x1736},
 {0x1740, 0x1753},
 {0x1760, 0x176c},
 {0x176e, 0x1770},
@@ -319,8 +318,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1780, 0x17dd},
 {0x17e0, 0x17e9},
 {0x17f0, 0x17f9},
-{0x1800, 0x180e},
-{0x1810, 0x1819},
+{0x1800, 0x1819},
 {0x1820, 0x1878},
 {0x1880, 0x18aa},
 {0x18b0, 0x18f5},
@@ -339,9 +337,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1a7f, 0x1a89},
 {0x1a90, 0x1a99},
 {0x1aa0, 0x1aad},
-{0x1ab0, 0x1ac0},
-{0x1b00, 0x1b4b},
-{0x1b50, 0x1b7c},
+{0x1ab0, 0x1ace},
+{0x1b00, 0x1b4c},
+{0x1b50, 0x1b7e},
 {0x1b80, 0x1bf3},
 {0x1bfc, 0x1c37},
 {0x1c3b, 0x1c49},
@@ -349,8 +347,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1c90, 0x1cba},
 {0x1cbd, 0x1cc7},
 {0x1cd0, 0x1cfa},
-{0x1d00, 0x1df9},
-{0x1dfb, 0x1f15},
+{0x1d00, 0x1f15},
 {0x1f18, 0x1f1d},
 {0x1f20, 0x1f45},
 {0x1f48, 0x1f4d},
@@ -401,7 +398,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x20a9, 0x20a9},
 {0x20aa, 0x20ab},
 {0x20ac, 0x20ac},
-{0x20ad, 0x20bf},
+{0x20ad, 0x20c0},
 {0x20d0, 0x20f0},
 {0x2100, 0x2102},
 {0x2103, 0x2103},
@@ -641,9 +638,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x2b56, 0x2b59},
 {0x2b5a, 0x2b73},
 {0x2b76, 0x2b95},
-{0x2b97, 0x2c2e},
-{0x2c30, 0x2c5e},
-{0x2c60, 0x2cf3},
+{0x2b97, 0x2cf3},
 {0x2cf9, 0x2d25},
 {0x2d27, 0x2d27},
 {0x2d2d, 0x2d2d},
@@ -658,11 +653,11 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x2dc8, 0x2dce},
 {0x2dd0, 0x2dd6},
 {0x2dd8, 0x2dde},
-{0x2de0, 0x2e52},
+{0x2de0, 0x2e5d},
 {0x2e80, 0x2e99},
 {0x2e9b, 0x2ef3},
 {0x2f00, 0x2fd5},
-{0x2ff0, 0x2ffb},
+{0x2ff0, 0x2fff},
 {0x3000, 0x3000},
 {0x3001, 0x303e},
 {0x303f, 0x303f},
@@ -671,7 +666,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x3105, 0x312f},
 {0x3131, 0x318e},
 {0x3190, 0x31e3},
-{0x31f0, 0x321e},
+{0x31ef, 0x321e},
 {0x3220, 0x3247},
 {0x3248, 0x324f},
 {0x3250, 0x4dbf},
@@ -680,9 +675,11 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0xa490, 0xa4c6},
 {0xa4d0, 0xa62b},
 {0xa640, 0xa6f7},
-{0xa700, 0xa7bf},
-{0xa7c2, 0xa7ca},
-{0xa7f5, 0xa82c},
+{0xa700, 0xa7ca},
+{0xa7d0, 0xa7d1},
+{0xa7d3, 0xa7d3},
+{0xa7d5, 0xa7d9},
+{0xa7f2, 0xa82c},
 {0xa830, 0xa839},
 {0xa840, 0xa877},
 {0xa880, 0xa8c5},
@@ -719,11 +716,11 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0xfb3e, 0xfb3e},
 {0xfb40, 0xfb41},
 {0xfb43, 0xfb44},
-{0xfb46, 0xfbc1},
-{0xfbd3, 0xfd3f},
-{0xfd50, 0xfd8f},
+{0xfb46, 0xfbc2},
+{0xfbd3, 0xfd8f},
 {0xfd92, 0xfdc7},
-{0xfdf0, 0xfdfd},
+{0xfdcf, 0xfdcf},
+{0xfdf0, 0xfdff},
 {0xfe00, 0xfe0f},
 {0xfe10, 0xfe19},
 {0xfe20, 0xfe2f},
@@ -771,10 +768,20 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x104d8, 0x104fb},
 {0x10500, 0x10527},
 {0x10530, 0x10563},
-{0x1056f, 0x1056f},
+{0x1056f, 0x1057a},
+{0x1057c, 0x1058a},
+{0x1058c, 0x10592},
+{0x10594, 0x10595},
+{0x10597, 0x105a1},
+{0x105a3, 0x105b1},
+{0x105b3, 0x105b9},
+{0x105bb, 0x105bc},
 {0x10600, 0x10736},
 {0x10740, 0x10755},
 {0x10760, 0x10767},
+{0x10780, 0x10785},
+{0x10787, 0x107b0},
+{0x107b2, 0x107ba},
 {0x10800, 0x10805},
 {0x10808, 0x10808},
 {0x1080a, 0x10835},
@@ -816,13 +823,14 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x10e80, 0x10ea9},
 {0x10eab, 0x10ead},
 {0x10eb0, 0x10eb1},
-{0x10f00, 0x10f27},
+{0x10efd, 0x10f27},
 {0x10f30, 0x10f59},
+{0x10f70, 0x10f89},
 {0x10fb0, 0x10fcb},
 {0x10fe0, 0x10ff6},
 {0x11000, 0x1104d},
-{0x11052, 0x1106f},
-{0x1107f, 0x110c1},
+{0x11052, 0x11075},
+{0x1107f, 0x110c2},
 {0x110cd, 0x110cd},
 {0x110d0, 0x110e8},
 {0x110f0, 0x110f9},
@@ -832,7 +840,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11180, 0x111df},
 {0x111e1, 0x111f4},
 {0x11200, 0x11211},
-{0x11213, 0x1123e},
+{0x11213, 0x11241},
 {0x11280, 0x11286},
 {0x11288, 0x11288},
 {0x1128a, 0x1128d},
@@ -864,11 +872,11 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11600, 0x11644},
 {0x11650, 0x11659},
 {0x11660, 0x1166c},
-{0x11680, 0x116b8},
+{0x11680, 0x116b9},
 {0x116c0, 0x116c9},
 {0x11700, 0x1171a},
 {0x1171d, 0x1172b},
-{0x11730, 0x1173f},
+{0x11730, 0x11746},
 {0x11800, 0x1183b},
 {0x118a0, 0x118f2},
 {0x118ff, 0x11906},
@@ -884,7 +892,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x119da, 0x119e4},
 {0x11a00, 0x11a47},
 {0x11a50, 0x11aa2},
-{0x11ac0, 0x11af8},
+{0x11ab0, 0x11af8},
+{0x11b00, 0x11b09},
 {0x11c00, 0x11c08},
 {0x11c0a, 0x11c36},
 {0x11c38, 0x11c45},
@@ -906,19 +915,23 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11d93, 0x11d98},
 {0x11da0, 0x11da9},
 {0x11ee0, 0x11ef8},
+{0x11f00, 0x11f10},
+{0x11f12, 0x11f3a},
+{0x11f3e, 0x11f59},
 {0x11fb0, 0x11fb0},
 {0x11fc0, 0x11ff1},
 {0x11fff, 0x12399},
 {0x12400, 0x1246e},
 {0x12470, 0x12474},
 {0x12480, 0x12543},
-{0x13000, 0x1342e},
-{0x13430, 0x13438},
+{0x12f90, 0x12ff2},
+{0x13000, 0x13455},
 {0x14400, 0x14646},
 {0x16800, 0x16a38},
 {0x16a40, 0x16a5e},
 {0x16a60, 0x16a69},
-{0x16a6e, 0x16a6f},
+{0x16a6e, 0x16abe},
+{0x16ac0, 0x16ac9},
 {0x16ad0, 0x16aed},
 {0x16af0, 0x16af5},
 {0x16b00, 0x16b45},
@@ -935,8 +948,13 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x17000, 0x187f7},
 {0x18800, 0x18cd5},
 {0x18d00, 0x18d08},
-{0x1b000, 0x1b11e},
+{0x1aff0, 0x1aff3},
+{0x1aff5, 0x1affb},
+{0x1affd, 0x1affe},
+{0x1b000, 0x1b122},
+{0x1b132, 0x1b132},
 {0x1b150, 0x1b152},
+{0x1b155, 0x1b155},
 {0x1b164, 0x1b167},
 {0x1b170, 0x1b2fb},
 {0x1bc00, 0x1bc6a},
@@ -944,10 +962,14 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1bc80, 0x1bc88},
 {0x1bc90, 0x1bc99},
 {0x1bc9c, 0x1bca3},
+{0x1cf00, 0x1cf2d},
+{0x1cf30, 0x1cf46},
+{0x1cf50, 0x1cfc3},
 {0x1d000, 0x1d0f5},
 {0x1d100, 0x1d126},
-{0x1d129, 0x1d1e8},
+{0x1d129, 0x1d1ea},
 {0x1d200, 0x1d245},
+{0x1d2c0, 0x1d2d3},
 {0x1d2e0, 0x1d2f3},
 {0x1d300, 0x1d356},
 {0x1d360, 0x1d378},
@@ -974,17 +996,27 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1d7ce, 0x1da8b},
 {0x1da9b, 0x1da9f},
 {0x1daa1, 0x1daaf},
+{0x1df00, 0x1df1e},
+{0x1df25, 0x1df2a},
 {0x1e000, 0x1e006},
 {0x1e008, 0x1e018},
 {0x1e01b, 0x1e021},
 {0x1e023, 0x1e024},
 {0x1e026, 0x1e02a},
+{0x1e030, 0x1e06d},
+{0x1e08f, 0x1e08f},
 {0x1e100, 0x1e12c},
 {0x1e130, 0x1e13d},
 {0x1e140, 0x1e149},
 {0x1e14e, 0x1e14f},
+{0x1e290, 0x1e2ae},
 {0x1e2c0, 0x1e2f9},
 {0x1e2ff, 0x1e2ff},
+{0x1e4d0, 0x1e4f9},
+{0x1e7e0, 0x1e7e6},
+{0x1e7e8, 0x1e7eb},
+{0x1e7ed, 0x1e7ee},
+{0x1e7f0, 0x1e7fe},
 {0x1e800, 0x1e8c4},
 {0x1e8c7, 0x1e8d6},
 {0x1e900, 0x1e94b},
@@ -1096,13 +1128,15 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1f6d0, 0x1f6d2},
 {0x1f6d3, 0x1f6d4},
 {0x1f6d5, 0x1f6d7},
+{0x1f6dc, 0x1f6df},
 {0x1f6e0, 0x1f6ea},
 {0x1f6eb, 0x1f6ec},
 {0x1f6f0, 0x1f6f3},
 {0x1f6f4, 0x1f6fc},
-{0x1f700, 0x1f773},
-{0x1f780, 0x1f7d8},
+{0x1f700, 0x1f776},
+{0x1f77b, 0x1f7d9},
 {0x1f7e0, 0x1f7eb},
+{0x1f7f0, 0x1f7f0},
 {0x1f800, 0x1f80b},
 {0x1f810, 0x1f847},
 {0x1f850, 0x1f859},
@@ -1114,18 +1148,16 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1f93b, 0x1f93b},
 {0x1f93c, 0x1f945},
 {0x1f946, 0x1f946},
-{0x1f947, 0x1f978},
-{0x1f97a, 0x1f9cb},
-{0x1f9cd, 0x1f9ff},
+{0x1f947, 0x1f9ff},
 {0x1fa00, 0x1fa53},
 {0x1fa60, 0x1fa6d},
-{0x1fa70, 0x1fa74},
-{0x1fa78, 0x1fa7a},
-{0x1fa80, 0x1fa86},
-{0x1fa90, 0x1faa8},
-{0x1fab0, 0x1fab6},
-{0x1fac0, 0x1fac2},
-{0x1fad0, 0x1fad6},
+{0x1fa70, 0x1fa7c},
+{0x1fa80, 0x1fa88},
+{0x1fa90, 0x1fabd},
+{0x1fabf, 0x1fac5},
+{0x1face, 0x1fadb},
+{0x1fae0, 0x1fae8},
+{0x1faf0, 0x1faf8},
 {0x1fb00, 0x1fb92},
 {0x1fb94, 0x1fbca},
 {0x1fbf0, 0x1fbf9},
@@ -1504,9 +1536,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
@@ -1797,8 +1826,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
@@ -1829,6 +1856,8 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2070,6 +2099,22 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
@@ -2079,6 +2124,25 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2236,6 +2300,7 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
@@ -2243,6 +2308,7 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2255,8 +2321,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
