@@ -34,7 +34,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0825 & 0xFF, 0x0827 & 0xFF},
 	{0x0829 & 0xFF, 0x082d & 0xFF},
 	{0x0859 & 0xFF, 0x085b & 0xFF},
-	{0x08d3 & 0xFF, 0x08e1 & 0xFF},
+	{0x0890 & 0xFF, 0x0891 & 0xFF},
+	{0x0898 & 0xFF, 0x089f & 0xFF},
+	{0x08ca & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
 	{0x0900 & 0xFF, 0x0902 & 0xFF},
@@ -105,6 +107,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c00 & 0xFF, 0x0c00 & 0xFF},
 	{0x0c01 & 0xFF, 0x0c03 & 0xFF},
 	{0x0c04 & 0xFF, 0x0c04 & 0xFF},
+	{0x0c3c & 0xFF, 0x0c3c & 0xFF},
 	{0x0c3e & 0xFF, 0x0c40 & 0xFF},
 	{0x0c41 & 0xFF, 0x0c44 & 0xFF},
 	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
@@ -125,6 +128,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0ccc & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
 	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
+	{0x0cf3 & 0xFF, 0x0cf3 & 0xFF},
 	{0x0d00 & 0xFF, 0x0d01 & 0xFF},
 	{0x0d02 & 0xFF, 0x0d03 & 0xFF},
 	{0x0d3b & 0xFF, 0x0d3c & 0xFF},
@@ -154,7 +158,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0eb1 & 0xFF, 0x0eb1 & 0xFF},
 	{0x0eb3 & 0xFF, 0x0eb3 & 0xFF},
 	{0x0eb4 & 0xFF, 0x0ebc & 0xFF},
-	{0x0ec8 & 0xFF, 0x0ecd & 0xFF},
+	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
 	{0x0f18 & 0xFF, 0x0f19 & 0xFF},
 	{0x0f35 & 0xFF, 0x0f35 & 0xFF},
 	{0x0f37 & 0xFF, 0x0f37 & 0xFF},
@@ -187,7 +191,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a8 & 0xFF, 0x11ff & 0xFF},
 	{0x135d & 0xFF, 0x135f & 0xFF},
 	{0x1712 & 0xFF, 0x1714 & 0xFF},
-	{0x1732 & 0xFF, 0x1734 & 0xFF},
+	{0x1715 & 0xFF, 0x1715 & 0xFF},
+	{0x1732 & 0xFF, 0x1733 & 0xFF},
+	{0x1734 & 0xFF, 0x1734 & 0xFF},
 	{0x1752 & 0xFF, 0x1753 & 0xFF},
 	{0x1772 & 0xFF, 0x1773 & 0xFF},
 	{0x17b4 & 0xFF, 0x17b5 & 0xFF},
@@ -200,6 +206,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x17dd & 0xFF, 0x17dd & 0xFF},
 	{0x180b & 0xFF, 0x180d & 0xFF},
 	{0x180e & 0xFF, 0x180e & 0xFF},
+	{0x180f & 0xFF, 0x180f & 0xFF},
 	{0x1885 & 0xFF, 0x1886 & 0xFF},
 	{0x18a9 & 0xFF, 0x18a9 & 0xFF},
 	{0x1920 & 0xFF, 0x1922 & 0xFF},
@@ -223,7 +230,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a6d & 0xFF, 0x1a72 & 0xFF},
 	{0x1a73 & 0xFF, 0x1a7c & 0xFF},
 	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ac0 & 0xFF},
+	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
 	{0x1b00 & 0xFF, 0x1b03 & 0xFF},
 	{0x1b04 & 0xFF, 0x1b04 & 0xFF},
 	{0x1b34 & 0xFF, 0x1b3a & 0xFF},
@@ -261,8 +268,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1cf4 & 0xFF, 0x1cf4 & 0xFF},
 	{0x1cf7 & 0xFF, 0x1cf7 & 0xFF},
 	{0x1cf8 & 0xFF, 0x1cf9 & 0xFF},
-	{0x1dc0 & 0xFF, 0x1df9 & 0xFF},
-	{0x1dfb & 0xFF, 0x1dff & 0xFF},
+	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
 	{0x200b & 0xFF, 0x200b & 0xFF},
 	{0x200c & 0xFF, 0x200c & 0xFF},
 	{0x200d & 0xFF, 0x200d & 0xFF},
@@ -1184,11 +1190,15 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10ae5 & 0xFF, 0x10ae6 & 0xFF},
 	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
+	{0x10efd & 0xFF, 0x10eff & 0xFF},
 	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
+	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
 	{0x11000 & 0xFF, 0x11000 & 0xFF},
 	{0x11001 & 0xFF, 0x11001 & 0xFF},
 	{0x11002 & 0xFF, 0x11002 & 0xFF},
 	{0x11038 & 0xFF, 0x11046 & 0xFF},
+	{0x11070 & 0xFF, 0x11070 & 0xFF},
+	{0x11073 & 0xFF, 0x11074 & 0xFF},
 	{0x1107f & 0xFF, 0x11081 & 0xFF},
 	{0x11082 & 0xFF, 0x11082 & 0xFF},
 	{0x110b0 & 0xFF, 0x110b2 & 0xFF},
@@ -1196,6 +1206,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x110b7 & 0xFF, 0x110b8 & 0xFF},
 	{0x110b9 & 0xFF, 0x110ba & 0xFF},
 	{0x110bd & 0xFF, 0x110bd & 0xFF},
+	{0x110c2 & 0xFF, 0x110c2 & 0xFF},
 	{0x110cd & 0xFF, 0x110cd & 0xFF},
 	{0x11100 & 0xFF, 0x11102 & 0xFF},
 	{0x11127 & 0xFF, 0x1112b & 0xFF},
@@ -1219,6 +1230,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11235 & 0xFF, 0x11235 & 0xFF},
 	{0x11236 & 0xFF, 0x11237 & 0xFF},
 	{0x1123e & 0xFF, 0x1123e & 0xFF},
+	{0x11241 & 0xFF, 0x11241 & 0xFF},
 	{0x112df & 0xFF, 0x112df & 0xFF},
 	{0x112e0 & 0xFF, 0x112e2 & 0xFF},
 	{0x112e3 & 0xFF, 0x112ea & 0xFF},
@@ -1275,7 +1287,6 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x116b6 & 0xFF, 0x116b6 & 0xFF},
 	{0x116b7 & 0xFF, 0x116b7 & 0xFF},
 	{0x1171d & 0xFF, 0x1171f & 0xFF},
-	{0x11720 & 0xFF, 0x11721 & 0xFF},
 	{0x11722 & 0xFF, 0x11725 & 0xFF},
 	{0x11726 & 0xFF, 0x11726 & 0xFF},
 	{0x11727 & 0xFF, 0x1172b & 0xFF},
@@ -1339,7 +1350,18 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11d97 & 0xFF, 0x11d97 & 0xFF},
 	{0x11ef3 & 0xFF, 0x11ef4 & 0xFF},
 	{0x11ef5 & 0xFF, 0x11ef6 & 0xFF},
-	{0x13430 & 0xFF, 0x13438 & 0xFF},
+	{0x11f00 & 0xFF, 0x11f01 & 0xFF},
+	{0x11f02 & 0xFF, 0x11f02 & 0xFF},
+	{0x11f03 & 0xFF, 0x11f03 & 0xFF},
+	{0x11f34 & 0xFF, 0x11f35 & 0xFF},
+	{0x11f36 & 0xFF, 0x11f3a & 0xFF},
+	{0x11f3e & 0xFF, 0x11f3f & 0xFF},
+	{0x11f40 & 0xFF, 0x11f40 & 0xFF},
+	{0x11f41 & 0xFF, 0x11f41 & 0xFF},
+	{0x11f42 & 0xFF, 0x11f42 & 0xFF},
+	{0x13430 & 0xFF, 0x1343f & 0xFF},
+	{0x13440 & 0xFF, 0x13440 & 0xFF},
+	{0x13447 & 0xFF, 0x13455 & 0xFF},
 	{0x16af0 & 0xFF, 0x16af4 & 0xFF},
 	{0x16b30 & 0xFF, 0x16b36 & 0xFF},
 	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
@@ -1349,6 +1371,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
 	{0x1bc9d & 0xFF, 0x1bc9e & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
+	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
+	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
 	{0x1d165 & 0xFF, 0x1d165 & 0xFF},
 	{0x1d166 & 0xFF, 0x1d166 & 0xFF},
 	{0x1d167 & 0xFF, 0x1d169 & 0xFF},
@@ -1370,8 +1394,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
 	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
 	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
+	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
 	{0x1e130 & 0xFF, 0x1e136 & 0xFF},
+	{0x1e2ae & 0xFF, 0x1e2ae & 0xFF},
 	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
+	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
 	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
 	{0x1e944 & 0xFF, 0x1e94a & 0xFF},
 	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
@@ -1432,6 +1459,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Prepend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Prepend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1504,6 +1533,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1523,6 +1553,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1585,7 +1616,9 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_T,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -1601,6 +1634,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -1660,7 +1694,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_ZWJ,
@@ -2583,17 +2616,22 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Prepend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Prepend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2618,6 +2656,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2673,7 +2712,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
-	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2737,10 +2775,21 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Prepend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2748,6 +2797,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2772,6 +2823,9 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Regional_Indicator,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
@@ -2896,17 +2950,20 @@ static const size_t unicode_starting_indextab[]={
 	284,
 	285,
 	286,
+	287,
 	308,
 	362,
 	363,
 	367,
 	444,
+	463,
 	465,
 	466,
 	474,
 	480,
 	481,
 	482,
+	484,
 	488,
 	489,
 	497,
@@ -2937,130 +2994,133 @@ static const char32_t unicode_starting_pagetab[]={
 	14,
 	24,
 	30,
-	38,
-	62,
-	83,
-	103,
-	126,
-	148,
-	156,
-	168,
-	183,
-	186,
+	40,
+	64,
+	85,
+	105,
+	130,
+	152,
+	160,
+	172,
 	187,
-	199,
-	203,
-	211,
-	225,
-	250,
-	262,
-	264,
-	271,
-	272,
-	274,
-	276,
+	190,
+	191,
+	205,
+	210,
+	218,
+	232,
+	257,
+	269,
+	270,
+	277,
+	278,
 	280,
-	292,
-	305,
-	324,
-	331,
-	351,
-	370,
-	389,
-	408,
-	427,
-	446,
-	465,
-	485,
-	504,
-	523,
-	542,
-	561,
-	580,
-	599,
-	619,
-	638,
-	657,
-	676,
-	695,
-	714,
-	733,
-	753,
-	772,
-	791,
-	810,
-	829,
-	848,
-	867,
-	887,
-	906,
-	925,
-	944,
-	963,
-	982,
-	1001,
-	1021,
-	1040,
-	1059,
-	1078,
-	1097,
-	1116,
-	1135,
-	1155,
-	1168,
-	1169,
-	1172,
+	282,
+	286,
+	298,
+	311,
+	330,
+	337,
+	357,
+	376,
+	395,
+	414,
+	433,
+	452,
+	471,
+	491,
+	510,
+	529,
+	548,
+	567,
+	586,
+	605,
+	625,
+	644,
+	663,
+	682,
+	701,
+	720,
+	739,
+	759,
+	778,
+	797,
+	816,
+	835,
+	854,
+	873,
+	893,
+	912,
+	931,
+	950,
+	969,
+	988,
+	1007,
+	1027,
+	1046,
+	1065,
+	1084,
+	1103,
+	1122,
+	1141,
+	1161,
 	1174,
 	1175,
-	1176,
-	1177,
+	1178,
+	1180,
+	1181,
+	1182,
 	1183,
-	1184,
-	1185,
-	1186,
-	1198,
-	1213,
-	1223,
-	1236,
-	1254,
-	1262,
-	1275,
-	1280,
-	1284,
-	1301,
-	1314,
-	1326,
-	1338,
-	1340,
-	1341,
-	1342,
-	1343,
-	1348,
-	1350,
-	1359,
+	1189,
+	1190,
+	1192,
+	1194,
+	1209,
+	1224,
+	1235,
+	1248,
+	1266,
+	1274,
+	1287,
+	1291,
+	1295,
+	1312,
+	1325,
+	1337,
+	1349,
+	1351,
 	1360,
-	1366,
-	1371,
+	1363,
+	1364,
+	1365,
+	1370,
 	1372,
-	1373,
 	1374,
-	1375,
-	1376,
-	1377,
-	1380,
-	1382,
 	1383,
 	1384,
-	1385,
-	1386,
-	1387,
-	1388,
-	1389,
 	1390,
-	1391,
-	1392,
-	1393,
-	1394,
-	1395
+	1396,
+	1397,
+	1399,
+	1400,
+	1401,
+	1402,
+	1403,
+	1404,
+	1407,
+	1409,
+	1410,
+	1411,
+	1412,
+	1413,
+	1414,
+	1415,
+	1416,
+	1417,
+	1418,
+	1419,
+	1420,
+	1421,
+	1422
 };
 
