@@ -53,8 +53,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x060c & 0xFF, 0x060c & 0xFF},
 	{0x060d & 0xFF, 0x061a & 0xFF},
 	{0x061b & 0xFF, 0x061b & 0xFF},
-	{0x061c & 0xFF, 0x061c & 0xFF},
-	{0x061e & 0xFF, 0x061e & 0xFF},
+	{0x061c & 0xFF, 0x061e & 0xFF},
 	{0x061f & 0xFF, 0x061f & 0xFF},
 	{0x0620 & 0xFF, 0x063f & 0xFF},
 	{0x0640 & 0xFF, 0x0640 & 0xFF},
@@ -77,9 +76,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0840 & 0xFF, 0x085b & 0xFF},
 	{0x085e & 0xFF, 0x085e & 0xFF},
 	{0x0860 & 0xFF, 0x086a & 0xFF},
-	{0x08a0 & 0xFF, 0x08b4 & 0xFF},
-	{0x08b6 & 0xFF, 0x08c7 & 0xFF},
-	{0x08d3 & 0xFF, 0x08e1 & 0xFF},
+	{0x0870 & 0xFF, 0x088e & 0xFF},
+	{0x0890 & 0xFF, 0x0891 & 0xFF},
+	{0x0898 & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
 	{0x0900 & 0xFF, 0x0950 & 0xFF},
@@ -165,11 +164,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c0e & 0xFF, 0x0c10 & 0xFF},
 	{0x0c12 & 0xFF, 0x0c28 & 0xFF},
 	{0x0c2a & 0xFF, 0x0c39 & 0xFF},
-	{0x0c3d & 0xFF, 0x0c44 & 0xFF},
+	{0x0c3c & 0xFF, 0x0c44 & 0xFF},
 	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
 	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
 	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
 	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
+	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
 	{0x0c60 & 0xFF, 0x0c63 & 0xFF},
 	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
 	{0x0c77 & 0xFF, 0x0c7f & 0xFF},
@@ -182,10 +182,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
 	{0x0cca & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
-	{0x0cde & 0xFF, 0x0cde & 0xFF},
+	{0x0cdd & 0xFF, 0x0cde & 0xFF},
 	{0x0ce0 & 0xFF, 0x0ce3 & 0xFF},
 	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
-	{0x0cf1 & 0xFF, 0x0cf2 & 0xFF},
+	{0x0cf1 & 0xFF, 0x0cf3 & 0xFF},
 	{0x0d00 & 0xFF, 0x0d0c & 0xFF},
 	{0x0d0e & 0xFF, 0x0d10 & 0xFF},
 	{0x0d12 & 0xFF, 0x0d44 & 0xFF},
@@ -216,7 +216,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0ea7 & 0xFF, 0x0ebd & 0xFF},
 	{0x0ec0 & 0xFF, 0x0ec4 & 0xFF},
 	{0x0ec6 & 0xFF, 0x0ec6 & 0xFF},
-	{0x0ec8 & 0xFF, 0x0ecd & 0xFF},
+	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
 	{0x0ed0 & 0xFF, 0x0ed9 & 0xFF},
 	{0x0edc & 0xFF, 0x0edf & 0xFF},
 	{0x0f00 & 0xFF, 0x0f47 & 0xFF},
@@ -263,8 +263,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16a0 & 0xFF, 0x16ea & 0xFF},
 	{0x16eb & 0xFF, 0x16ed & 0xFF},
 	{0x16ee & 0xFF, 0x16f8 & 0xFF},
-	{0x1700 & 0xFF, 0x170c & 0xFF},
-	{0x170e & 0xFF, 0x1714 & 0xFF},
+	{0x1700 & 0xFF, 0x1715 & 0xFF},
+	{0x171f & 0xFF, 0x171f & 0xFF},
 	{0x1720 & 0xFF, 0x1734 & 0xFF},
 	{0x1735 & 0xFF, 0x1736 & 0xFF},
 	{0x1740 & 0xFF, 0x1753 & 0xFF},
@@ -278,8 +278,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1802 & 0xFF, 0x1803 & 0xFF},
 	{0x1804 & 0xFF, 0x1804 & 0xFF},
 	{0x1805 & 0xFF, 0x1805 & 0xFF},
-	{0x1806 & 0xFF, 0x180e & 0xFF},
-	{0x1810 & 0xFF, 0x1819 & 0xFF},
+	{0x1806 & 0xFF, 0x1819 & 0xFF},
 	{0x1820 & 0xFF, 0x1878 & 0xFF},
 	{0x1880 & 0xFF, 0x18aa & 0xFF},
 	{0x18b0 & 0xFF, 0x18f5 & 0xFF},
@@ -302,9 +301,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a7f & 0xFF, 0x1a89 & 0xFF},
 	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
 	{0x1aa0 & 0xFF, 0x1aad & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ac0 & 0xFF},
-	{0x1b00 & 0xFF, 0x1b4b & 0xFF},
-	{0x1b50 & 0xFF, 0x1b7c & 0xFF},
+	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
+	{0x1b00 & 0xFF, 0x1b4c & 0xFF},
+	{0x1b50 & 0xFF, 0x1b7e & 0xFF},
 	{0x1b80 & 0xFF, 0x1bbf & 0xFF},
 	{0x1bc0 & 0xFF, 0x1bf3 & 0xFF},
 	{0x1bfc & 0xFF, 0x1bff & 0xFF},
@@ -339,8 +338,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1d78 & 0xFF, 0x1d78 & 0xFF},
 	{0x1d79 & 0xFF, 0x1dbe & 0xFF},
 	{0x1dbf & 0xFF, 0x1dbf & 0xFF},
-	{0x1dc0 & 0xFF, 0x1df9 & 0xFF},
-	{0x1dfb & 0xFF, 0x1dff & 0xFF},
+	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
 	{0x1e00 & 0xFF, 0x1eff & 0xFF},
 	{0x1f00 & 0xFF, 0x1f15 & 0xFF},
 	{0x1f18 & 0xFF, 0x1f1d & 0xFF},
@@ -367,7 +365,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x207f & 0xFF, 0x207f & 0xFF},
 	{0x2080 & 0xFF, 0x208e & 0xFF},
 	{0x2090 & 0xFF, 0x209c & 0xFF},
-	{0x20a0 & 0xFF, 0x20bf & 0xFF},
+	{0x20a0 & 0xFF, 0x20c0 & 0xFF},
 	{0x20d0 & 0xFF, 0x20f0 & 0xFF},
 	{0x2100 & 0xFF, 0x2125 & 0xFF},
 	{0x2126 & 0xFF, 0x2126 & 0xFF},
@@ -395,8 +393,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2b00 & 0xFF, 0x2b73 & 0xFF},
 	{0x2b76 & 0xFF, 0x2b95 & 0xFF},
 	{0x2b97 & 0xFF, 0x2bff & 0xFF},
-	{0x2c00 & 0xFF, 0x2c2e & 0xFF},
-	{0x2c30 & 0xFF, 0x2c5e & 0xFF},
+	{0x2c00 & 0xFF, 0x2c5f & 0xFF},
 	{0x2c60 & 0xFF, 0x2c7f & 0xFF},
 	{0x2c80 & 0xFF, 0x2cf3 & 0xFF},
 	{0x2cf9 & 0xFF, 0x2cff & 0xFF},
@@ -416,11 +413,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2dd0 & 0xFF, 0x2dd6 & 0xFF},
 	{0x2dd8 & 0xFF, 0x2dde & 0xFF},
 	{0x2de0 & 0xFF, 0x2dff & 0xFF},
-	{0x2e00 & 0xFF, 0x2e52 & 0xFF},
+	{0x2e00 & 0xFF, 0x2e5d & 0xFF},
 	{0x2e80 & 0xFF, 0x2e99 & 0xFF},
 	{0x2e9b & 0xFF, 0x2ef3 & 0xFF},
 	{0x2f00 & 0xFF, 0x2fd5 & 0xFF},
-	{0x2ff0 & 0xFF, 0x2ffb & 0xFF},
+	{0x2ff0 & 0xFF, 0x2fff & 0xFF},
 	{0x3000 & 0xFF, 0x3004 & 0xFF},
 	{0x3005 & 0xFF, 0x3005 & 0xFF},
 	{0x3006 & 0xFF, 0x3006 & 0xFF},
@@ -445,6 +442,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x3190 & 0xFF, 0x319f & 0xFF},
 	{0x31a0 & 0xFF, 0x31bf & 0xFF},
 	{0x31c0 & 0xFF, 0x31e3 & 0xFF},
+	{0x31ef & 0xFF, 0x31ef & 0xFF},
 	{0x31f0 & 0xFF, 0x31ff & 0xFF},
 	{0x3200 & 0xFF, 0x321e & 0xFF},
 	{0x3220 & 0xFF, 0x325f & 0xFF},
@@ -562,7 +560,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x9c00 & 0xFF, 0x9cff & 0xFF},
 	{0x9d00 & 0xFF, 0x9dff & 0xFF},
 	{0x9e00 & 0xFF, 0x9eff & 0xFF},
-	{0x9f00 & 0xFF, 0x9ffc & 0xFF},
+	{0x9f00 & 0xFF, 0x9fff & 0xFF},
 	{0xa000 & 0xFF, 0xa0ff & 0xFF},
 	{0xa100 & 0xFF, 0xa1ff & 0xFF},
 	{0xa200 & 0xFF, 0xa2ff & 0xFF},
@@ -577,9 +575,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa700 & 0xFF, 0xa721 & 0xFF},
 	{0xa722 & 0xFF, 0xa787 & 0xFF},
 	{0xa788 & 0xFF, 0xa78a & 0xFF},
-	{0xa78b & 0xFF, 0xa7bf & 0xFF},
-	{0xa7c2 & 0xFF, 0xa7ca & 0xFF},
-	{0xa7f5 & 0xFF, 0xa7ff & 0xFF},
+	{0xa78b & 0xFF, 0xa7ca & 0xFF},
+	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
+	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
+	{0xa7d5 & 0xFF, 0xa7d9 & 0xFF},
+	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa82c & 0xFF},
 	{0xa830 & 0xFF, 0xa839 & 0xFF},
 	{0xa840 & 0xFF, 0xa877 & 0xFF},
@@ -676,14 +676,15 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xfb40 & 0xFF, 0xfb41 & 0xFF},
 	{0xfb43 & 0xFF, 0xfb44 & 0xFF},
 	{0xfb46 & 0xFF, 0xfb4f & 0xFF},
-	{0xfb50 & 0xFF, 0xfbc1 & 0xFF},
+	{0xfb50 & 0xFF, 0xfbc2 & 0xFF},
 	{0xfbd3 & 0xFF, 0xfbff & 0xFF},
 	{0xfc00 & 0xFF, 0xfcff & 0xFF},
 	{0xfd00 & 0xFF, 0xfd3d & 0xFF},
 	{0xfd3e & 0xFF, 0xfd3f & 0xFF},
-	{0xfd50 & 0xFF, 0xfd8f & 0xFF},
+	{0xfd40 & 0xFF, 0xfd8f & 0xFF},
 	{0xfd92 & 0xFF, 0xfdc7 & 0xFF},
-	{0xfdf0 & 0xFF, 0xfdfd & 0xFF},
+	{0xfdcf & 0xFF, 0xfdcf & 0xFF},
+	{0xfdf0 & 0xFF, 0xfdff & 0xFF},
 	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
 	{0xfe10 & 0xFF, 0xfe19 & 0xFF},
 	{0xfe20 & 0xFF, 0xfe2d & 0xFF},
@@ -747,10 +748,21 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10500 & 0xFF, 0x10527 & 0xFF},
 	{0x10530 & 0xFF, 0x10563 & 0xFF},
 	{0x1056f & 0xFF, 0x1056f & 0xFF},
+	{0x10570 & 0xFF, 0x1057a & 0xFF},
+	{0x1057c & 0xFF, 0x1058a & 0xFF},
+	{0x1058c & 0xFF, 0x10592 & 0xFF},
+	{0x10594 & 0xFF, 0x10595 & 0xFF},
+	{0x10597 & 0xFF, 0x105a1 & 0xFF},
+	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
+	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
+	{0x105bb & 0xFF, 0x105bc & 0xFF},
 	{0x10600 & 0xFF, 0x106ff & 0xFF},
 	{0x10700 & 0xFF, 0x10736 & 0xFF},
 	{0x10740 & 0xFF, 0x10755 & 0xFF},
 	{0x10760 & 0xFF, 0x10767 & 0xFF},
+	{0x10780 & 0xFF, 0x10785 & 0xFF},
+	{0x10787 & 0xFF, 0x107b0 & 0xFF},
+	{0x107b2 & 0xFF, 0x107ba & 0xFF},
 	{0x10800 & 0xFF, 0x10805 & 0xFF},
 	{0x10808 & 0xFF, 0x10808 & 0xFF},
 	{0x1080a & 0xFF, 0x10835 & 0xFF},
@@ -804,14 +816,16 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10ead & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
+	{0x10efd & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f59 & 0xFF},
+	{0x10f70 & 0xFF, 0x10f89 & 0xFF},
 	{0x10fb0 & 0xFF, 0x10fcb & 0xFF},
 	{0x10fe0 & 0xFF, 0x10ff6 & 0xFF},
 	{0x11000 & 0xFF, 0x1104d & 0xFF},
-	{0x11052 & 0xFF, 0x1106f & 0xFF},
+	{0x11052 & 0xFF, 0x11075 & 0xFF},
 	{0x1107f & 0xFF, 0x1107f & 0xFF},
-	{0x11080 & 0xFF, 0x110c1 & 0xFF},
+	{0x11080 & 0xFF, 0x110c2 & 0xFF},
 	{0x110cd & 0xFF, 0x110cd & 0xFF},
 	{0x110d0 & 0xFF, 0x110e8 & 0xFF},
 	{0x110f0 & 0xFF, 0x110f9 & 0xFF},
@@ -821,7 +835,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11180 & 0xFF, 0x111df & 0xFF},
 	{0x111e1 & 0xFF, 0x111f4 & 0xFF},
 	{0x11200 & 0xFF, 0x11211 & 0xFF},
-	{0x11213 & 0xFF, 0x1123e & 0xFF},
+	{0x11213 & 0xFF, 0x11241 & 0xFF},
 	{0x11280 & 0xFF, 0x11286 & 0xFF},
 	{0x11288 & 0xFF, 0x11288 & 0xFF},
 	{0x1128a & 0xFF, 0x1128d & 0xFF},
@@ -854,11 +868,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11600 & 0xFF, 0x11644 & 0xFF},
 	{0x11650 & 0xFF, 0x11659 & 0xFF},
 	{0x11660 & 0xFF, 0x1166c & 0xFF},
-	{0x11680 & 0xFF, 0x116b8 & 0xFF},
+	{0x11680 & 0xFF, 0x116b9 & 0xFF},
 	{0x116c0 & 0xFF, 0x116c9 & 0xFF},
 	{0x11700 & 0xFF, 0x1171a & 0xFF},
 	{0x1171d & 0xFF, 0x1172b & 0xFF},
-	{0x11730 & 0xFF, 0x1173f & 0xFF},
+	{0x11730 & 0xFF, 0x11746 & 0xFF},
 	{0x11800 & 0xFF, 0x1183b & 0xFF},
 	{0x118a0 & 0xFF, 0x118f2 & 0xFF},
 	{0x118ff & 0xFF, 0x118ff & 0xFF},
@@ -875,7 +889,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x119da & 0xFF, 0x119e4 & 0xFF},
 	{0x11a00 & 0xFF, 0x11a47 & 0xFF},
 	{0x11a50 & 0xFF, 0x11aa2 & 0xFF},
+	{0x11ab0 & 0xFF, 0x11abf & 0xFF},
 	{0x11ac0 & 0xFF, 0x11af8 & 0xFF},
+	{0x11b00 & 0xFF, 0x11b09 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
 	{0x11c0a & 0xFF, 0x11c36 & 0xFF},
 	{0x11c38 & 0xFF, 0x11c45 & 0xFF},
@@ -897,6 +913,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11d93 & 0xFF, 0x11d98 & 0xFF},
 	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
 	{0x11ee0 & 0xFF, 0x11ef8 & 0xFF},
+	{0x11f00 & 0xFF, 0x11f10 & 0xFF},
+	{0x11f12 & 0xFF, 0x11f3a & 0xFF},
+	{0x11f3e & 0xFF, 0x11f59 & 0xFF},
 	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
 	{0x11fc0 & 0xFF, 0x11ff1 & 0xFF},
 	{0x11fff & 0xFF, 0x11fff & 0xFF},
@@ -908,12 +927,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x12470 & 0xFF, 0x12474 & 0xFF},
 	{0x12480 & 0xFF, 0x124ff & 0xFF},
 	{0x12500 & 0xFF, 0x12543 & 0xFF},
+	{0x12f90 & 0xFF, 0x12ff2 & 0xFF},
 	{0x13000 & 0xFF, 0x130ff & 0xFF},
 	{0x13100 & 0xFF, 0x131ff & 0xFF},
 	{0x13200 & 0xFF, 0x132ff & 0xFF},
 	{0x13300 & 0xFF, 0x133ff & 0xFF},
-	{0x13400 & 0xFF, 0x1342e & 0xFF},
-	{0x13430 & 0xFF, 0x13438 & 0xFF},
+	{0x13400 & 0xFF, 0x13455 & 0xFF},
 	{0x14400 & 0xFF, 0x144ff & 0xFF},
 	{0x14500 & 0xFF, 0x145ff & 0xFF},
 	{0x14600 & 0xFF, 0x14646 & 0xFF},
@@ -923,6 +942,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16a40 & 0xFF, 0x16a5e & 0xFF},
 	{0x16a60 & 0xFF, 0x16a69 & 0xFF},
 	{0x16a6e & 0xFF, 0x16a6f & 0xFF},
+	{0x16a70 & 0xFF, 0x16abe & 0xFF},
+	{0x16ac0 & 0xFF, 0x16ac9 & 0xFF},
 	{0x16ad0 & 0xFF, 0x16aed & 0xFF},
 	{0x16af0 & 0xFF, 0x16af5 & 0xFF},
 	{0x16b00 & 0xFF, 0x16b45 & 0xFF},
@@ -969,10 +990,16 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x18b00 & 0xFF, 0x18bff & 0xFF},
 	{0x18c00 & 0xFF, 0x18cd5 & 0xFF},
 	{0x18d00 & 0xFF, 0x18d08 & 0xFF},
+	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
+	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
+	{0x1affd & 0xFF, 0x1affe & 0xFF},
 	{0x1b000 & 0xFF, 0x1b000 & 0xFF},
 	{0x1b001 & 0xFF, 0x1b0ff & 0xFF},
-	{0x1b100 & 0xFF, 0x1b11e & 0xFF},
+	{0x1b100 & 0xFF, 0x1b11f & 0xFF},
+	{0x1b120 & 0xFF, 0x1b122 & 0xFF},
+	{0x1b132 & 0xFF, 0x1b132 & 0xFF},
 	{0x1b150 & 0xFF, 0x1b152 & 0xFF},
+	{0x1b155 & 0xFF, 0x1b155 & 0xFF},
 	{0x1b164 & 0xFF, 0x1b167 & 0xFF},
 	{0x1b170 & 0xFF, 0x1b1ff & 0xFF},
 	{0x1b200 & 0xFF, 0x1b2fb & 0xFF},
@@ -982,6 +1009,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
 	{0x1bc9c & 0xFF, 0x1bc9f & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
+	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
+	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
+	{0x1cf50 & 0xFF, 0x1cfc3 & 0xFF},
 	{0x1d000 & 0xFF, 0x1d0f5 & 0xFF},
 	{0x1d100 & 0xFF, 0x1d126 & 0xFF},
 	{0x1d129 & 0xFF, 0x1d166 & 0xFF},
@@ -992,8 +1022,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1d185 & 0xFF, 0x1d18b & 0xFF},
 	{0x1d18c & 0xFF, 0x1d1a9 & 0xFF},
 	{0x1d1aa & 0xFF, 0x1d1ad & 0xFF},
-	{0x1d1ae & 0xFF, 0x1d1e8 & 0xFF},
+	{0x1d1ae & 0xFF, 0x1d1ea & 0xFF},
 	{0x1d200 & 0xFF, 0x1d245 & 0xFF},
+	{0x1d2c0 & 0xFF, 0x1d2d3 & 0xFF},
 	{0x1d2e0 & 0xFF, 0x1d2f3 & 0xFF},
 	{0x1d300 & 0xFF, 0x1d356 & 0xFF},
 	{0x1d360 & 0xFF, 0x1d378 & 0xFF},
@@ -1026,17 +1057,27 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1da00 & 0xFF, 0x1da8b & 0xFF},
 	{0x1da9b & 0xFF, 0x1da9f & 0xFF},
 	{0x1daa1 & 0xFF, 0x1daaf & 0xFF},
+	{0x1df00 & 0xFF, 0x1df1e & 0xFF},
+	{0x1df25 & 0xFF, 0x1df2a & 0xFF},
 	{0x1e000 & 0xFF, 0x1e006 & 0xFF},
 	{0x1e008 & 0xFF, 0x1e018 & 0xFF},
 	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
 	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
 	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
+	{0x1e030 & 0xFF, 0x1e06d & 0xFF},
+	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
 	{0x1e100 & 0xFF, 0x1e12c & 0xFF},
 	{0x1e130 & 0xFF, 0x1e13d & 0xFF},
 	{0x1e140 & 0xFF, 0x1e149 & 0xFF},
 	{0x1e14e & 0xFF, 0x1e14f & 0xFF},
+	{0x1e290 & 0xFF, 0x1e2ae & 0xFF},
 	{0x1e2c0 & 0xFF, 0x1e2f9 & 0xFF},
 	{0x1e2ff & 0xFF, 0x1e2ff & 0xFF},
+	{0x1e4d0 & 0xFF, 0x1e4f9 & 0xFF},
+	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
+	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
+	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
+	{0x1e7f0 & 0xFF, 0x1e7fe & 0xFF},
 	{0x1e800 & 0xFF, 0x1e8c4 & 0xFF},
 	{0x1e8c7 & 0xFF, 0x1e8d6 & 0xFF},
 	{0x1e900 & 0xFF, 0x1e94b & 0xFF},
@@ -1096,29 +1137,28 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1f400 & 0xFF, 0x1f4ff & 0xFF},
 	{0x1f500 & 0xFF, 0x1f5ff & 0xFF},
 	{0x1f600 & 0xFF, 0x1f6d7 & 0xFF},
-	{0x1f6e0 & 0xFF, 0x1f6ec & 0xFF},
+	{0x1f6dc & 0xFF, 0x1f6ec & 0xFF},
 	{0x1f6f0 & 0xFF, 0x1f6fc & 0xFF},
-	{0x1f700 & 0xFF, 0x1f773 & 0xFF},
-	{0x1f780 & 0xFF, 0x1f7d8 & 0xFF},
+	{0x1f700 & 0xFF, 0x1f776 & 0xFF},
+	{0x1f77b & 0xFF, 0x1f7d9 & 0xFF},
 	{0x1f7e0 & 0xFF, 0x1f7eb & 0xFF},
+	{0x1f7f0 & 0xFF, 0x1f7f0 & 0xFF},
 	{0x1f800 & 0xFF, 0x1f80b & 0xFF},
 	{0x1f810 & 0xFF, 0x1f847 & 0xFF},
 	{0x1f850 & 0xFF, 0x1f859 & 0xFF},
 	{0x1f860 & 0xFF, 0x1f887 & 0xFF},
 	{0x1f890 & 0xFF, 0x1f8ad & 0xFF},
 	{0x1f8b0 & 0xFF, 0x1f8b1 & 0xFF},
-	{0x1f900 & 0xFF, 0x1f978 & 0xFF},
-	{0x1f97a & 0xFF, 0x1f9cb & 0xFF},
-	{0x1f9cd & 0xFF, 0x1f9ff & 0xFF},
+	{0x1f900 & 0xFF, 0x1f9ff & 0xFF},
 	{0x1fa00 & 0xFF, 0x1fa53 & 0xFF},
 	{0x1fa60 & 0xFF, 0x1fa6d & 0xFF},
-	{0x1fa70 & 0xFF, 0x1fa74 & 0xFF},
-	{0x1fa78 & 0xFF, 0x1fa7a & 0xFF},
-	{0x1fa80 & 0xFF, 0x1fa86 & 0xFF},
-	{0x1fa90 & 0xFF, 0x1faa8 & 0xFF},
-	{0x1fab0 & 0xFF, 0x1fab6 & 0xFF},
-	{0x1fac0 & 0xFF, 0x1fac2 & 0xFF},
-	{0x1fad0 & 0xFF, 0x1fad6 & 0xFF},
+	{0x1fa70 & 0xFF, 0x1fa7c & 0xFF},
+	{0x1fa80 & 0xFF, 0x1fa88 & 0xFF},
+	{0x1fa90 & 0xFF, 0x1fabd & 0xFF},
+	{0x1fabf & 0xFF, 0x1fac5 & 0xFF},
+	{0x1face & 0xFF, 0x1fadb & 0xFF},
+	{0x1fae0 & 0xFF, 0x1fae8 & 0xFF},
+	{0x1faf0 & 0xFF, 0x1faf8 & 0xFF},
 	{0x1fb00 & 0xFF, 0x1fb92 & 0xFF},
 	{0x1fb94 & 0xFF, 0x1fbca & 0xFF},
 	{0x1fbf0 & 0xFF, 0x1fbf9 & 0xFF},
@@ -1288,7 +1328,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2a300 & 0xFF, 0x2a3ff & 0xFF},
 	{0x2a400 & 0xFF, 0x2a4ff & 0xFF},
 	{0x2a500 & 0xFF, 0x2a5ff & 0xFF},
-	{0x2a600 & 0xFF, 0x2a6dd & 0xFF},
+	{0x2a600 & 0xFF, 0x2a6df & 0xFF},
 	{0x2a700 & 0xFF, 0x2a7ff & 0xFF},
 	{0x2a800 & 0xFF, 0x2a8ff & 0xFF},
 	{0x2a900 & 0xFF, 0x2a9ff & 0xFF},
@@ -1305,7 +1345,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2b400 & 0xFF, 0x2b4ff & 0xFF},
 	{0x2b500 & 0xFF, 0x2b5ff & 0xFF},
 	{0x2b600 & 0xFF, 0x2b6ff & 0xFF},
-	{0x2b700 & 0xFF, 0x2b734 & 0xFF},
+	{0x2b700 & 0xFF, 0x2b739 & 0xFF},
 	{0x2b740 & 0xFF, 0x2b7ff & 0xFF},
 	{0x2b800 & 0xFF, 0x2b81d & 0xFF},
 	{0x2b820 & 0xFF, 0x2b8ff & 0xFF},
@@ -1361,6 +1401,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2e900 & 0xFF, 0x2e9ff & 0xFF},
 	{0x2ea00 & 0xFF, 0x2eaff & 0xFF},
 	{0x2eb00 & 0xFF, 0x2ebe0 & 0xFF},
+	{0x2ebf0 & 0xFF, 0x2ebff & 0xFF},
+	{0x2ec00 & 0xFF, 0x2ecff & 0xFF},
+	{0x2ed00 & 0xFF, 0x2edff & 0xFF},
+	{0x2ee00 & 0xFF, 0x2ee5d & 0xFF},
 	{0x2f800 & 0xFF, 0x2f8ff & 0xFF},
 	{0x2f900 & 0xFF, 0x2f9ff & 0xFF},
 	{0x2fa00 & 0xFF, 0x2fa1d & 0xFF},
@@ -1384,6 +1428,23 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x31100 & 0xFF, 0x311ff & 0xFF},
 	{0x31200 & 0xFF, 0x312ff & 0xFF},
 	{0x31300 & 0xFF, 0x3134a & 0xFF},
+	{0x31350 & 0xFF, 0x313ff & 0xFF},
+	{0x31400 & 0xFF, 0x314ff & 0xFF},
+	{0x31500 & 0xFF, 0x315ff & 0xFF},
+	{0x31600 & 0xFF, 0x316ff & 0xFF},
+	{0x31700 & 0xFF, 0x317ff & 0xFF},
+	{0x31800 & 0xFF, 0x318ff & 0xFF},
+	{0x31900 & 0xFF, 0x319ff & 0xFF},
+	{0x31a00 & 0xFF, 0x31aff & 0xFF},
+	{0x31b00 & 0xFF, 0x31bff & 0xFF},
+	{0x31c00 & 0xFF, 0x31cff & 0xFF},
+	{0x31d00 & 0xFF, 0x31dff & 0xFF},
+	{0x31e00 & 0xFF, 0x31eff & 0xFF},
+	{0x31f00 & 0xFF, 0x31fff & 0xFF},
+	{0x32000 & 0xFF, 0x320ff & 0xFF},
+	{0x32100 & 0xFF, 0x321ff & 0xFF},
+	{0x32200 & 0xFF, 0x322ff & 0xFF},
+	{0x32300 & 0xFF, 0x323af & 0xFF},
 	{0xe0001 & 0xFF, 0xe0001 & 0xFF},
 	{0xe0020 & 0xFF, 0xe007f & 0xFF},
 	{0xe0100 & 0xFF, 0xe01ef & 0xFF}};
@@ -1444,7 +1505,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_arabic,
 	unicode_script_common,
 	unicode_script_arabic,
-	unicode_script_arabic,
 	unicode_script_common,
 	unicode_script_arabic,
 	unicode_script_common,
@@ -1563,6 +1623,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_telugu,
 	unicode_script_telugu,
 	unicode_script_telugu,
+	unicode_script_telugu,
 	unicode_script_kannada,
 	unicode_script_kannada,
 	unicode_script_kannada,
@@ -1671,7 +1732,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_mongolian,
 	unicode_script_mongolian,
 	unicode_script_mongolian,
-	unicode_script_mongolian,
 	unicode_script_canadian_aboriginal,
 	unicode_script_limbu,
 	unicode_script_limbu,
@@ -1730,7 +1790,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_latin,
 	unicode_script_greek,
 	unicode_script_inherited,
-	unicode_script_inherited,
 	unicode_script_latin,
 	unicode_script_greek,
 	unicode_script_greek,
@@ -1786,7 +1845,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_glagolitic,
-	unicode_script_glagolitic,
 	unicode_script_latin,
 	unicode_script_coptic,
 	unicode_script_coptic,
@@ -1835,6 +1893,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_bopomofo,
 	unicode_script_common,
+	unicode_script_common,
 	unicode_script_katakana,
 	unicode_script_hangul,
 	unicode_script_common,
@@ -1970,6 +2029,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_latin,
 	unicode_script_latin,
 	unicode_script_latin,
+	unicode_script_latin,
+	unicode_script_latin,
 	unicode_script_syloti_nagri,
 	unicode_script_common,
 	unicode_script_phags_pa,
@@ -2074,6 +2135,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_arabic,
 	unicode_script_arabic,
 	unicode_script_arabic,
+	unicode_script_arabic,
 	unicode_script_inherited,
 	unicode_script_common,
 	unicode_script_inherited,
@@ -2137,10 +2199,21 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_elbasan,
 	unicode_script_caucasian_albanian,
 	unicode_script_caucasian_albanian,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
+	unicode_script_vithkuqi,
 	unicode_script_linear_a,
 	unicode_script_linear_a,
 	unicode_script_linear_a,
 	unicode_script_linear_a,
+	unicode_script_latin,
+	unicode_script_latin,
+	unicode_script_latin,
 	unicode_script_cypriot,
 	unicode_script_cypriot,
 	unicode_script_cypriot,
@@ -2194,8 +2267,10 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_yezidi,
 	unicode_script_yezidi,
 	unicode_script_yezidi,
+	unicode_script_arabic,
 	unicode_script_old_sogdian,
 	unicode_script_sogdian,
+	unicode_script_old_uyghur,
 	unicode_script_chorasmian,
 	unicode_script_elymaic,
 	unicode_script_brahmi,
@@ -2265,7 +2340,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_nandinagari,
 	unicode_script_zanabazar_square,
 	unicode_script_soyombo,
+	unicode_script_canadian_aboriginal,
 	unicode_script_pau_cin_hau,
+	unicode_script_devanagari,
 	unicode_script_bhaiksuki,
 	unicode_script_bhaiksuki,
 	unicode_script_bhaiksuki,
@@ -2287,6 +2364,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_gunjala_gondi,
 	unicode_script_gunjala_gondi,
 	unicode_script_makasar,
+	unicode_script_kawi,
+	unicode_script_kawi,
+	unicode_script_kawi,
 	unicode_script_lisu,
 	unicode_script_tamil,
 	unicode_script_tamil,
@@ -2298,7 +2378,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_cuneiform,
 	unicode_script_cuneiform,
 	unicode_script_cuneiform,
-	unicode_script_egyptian_hieroglyphs,
+	unicode_script_cypro_minoan,
 	unicode_script_egyptian_hieroglyphs,
 	unicode_script_egyptian_hieroglyphs,
 	unicode_script_egyptian_hieroglyphs,
@@ -2313,6 +2393,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_mro,
 	unicode_script_mro,
 	unicode_script_mro,
+	unicode_script_tangsa,
+	unicode_script_tangsa,
 	unicode_script_bassa_vah,
 	unicode_script_bassa_vah,
 	unicode_script_pahawh_hmong,
@@ -2326,7 +2408,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_miao,
 	unicode_script_tangut,
 	unicode_script_nushu,
-	unicode_script_common,
+	unicode_script_han,
 	unicode_script_khitan_small_script,
 	unicode_script_han,
 	unicode_script_tangut,
@@ -2360,9 +2442,15 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_khitan_small_script,
 	unicode_script_tangut,
 	unicode_script_katakana,
+	unicode_script_katakana,
+	unicode_script_katakana,
+	unicode_script_katakana,
 	unicode_script_hiragana,
 	unicode_script_hiragana,
+	unicode_script_katakana,
 	unicode_script_hiragana,
+	unicode_script_hiragana,
+	unicode_script_katakana,
 	unicode_script_katakana,
 	unicode_script_nushu,
 	unicode_script_nushu,
@@ -2372,6 +2460,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_duployan,
 	unicode_script_duployan,
 	unicode_script_common,
+	unicode_script_inherited,
+	unicode_script_inherited,
+	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
@@ -2411,22 +2502,33 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
+	unicode_script_common,
 	unicode_script_signwriting,
 	unicode_script_signwriting,
 	unicode_script_signwriting,
 	unicode_script_signwriting,
 	unicode_script_signwriting,
+	unicode_script_latin,
+	unicode_script_latin,
 	unicode_script_glagolitic,
 	unicode_script_glagolitic,
 	unicode_script_glagolitic,
 	unicode_script_glagolitic,
 	unicode_script_glagolitic,
+	unicode_script_cyrillic,
+	unicode_script_cyrillic,
 	unicode_script_nyiakeng_puachue_hmong,
 	unicode_script_nyiakeng_puachue_hmong,
 	unicode_script_nyiakeng_puachue_hmong,
 	unicode_script_nyiakeng_puachue_hmong,
+	unicode_script_toto,
 	unicode_script_wancho,
 	unicode_script_wancho,
+	unicode_script_nag_mundari,
+	unicode_script_ethiopic,
+	unicode_script_ethiopic,
+	unicode_script_ethiopic,
+	unicode_script_ethiopic,
 	unicode_script_mende_kikakui,
 	unicode_script_mende_kikakui,
 	unicode_script_adlam,
@@ -2511,7 +2613,27 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
-	unicode_script_common,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
 	unicode_script_han,
 	unicode_script_han,
 	unicode_script_han,
@@ -3029,6 +3151,7 @@ static const size_t unicode_starting_indextab[]={
 	280,
 	281,
 	282,
+	283,
 	284,
 	285,
 	286,
@@ -3039,6 +3162,7 @@ static const size_t unicode_starting_indextab[]={
 	291,
 	292,
 	293,
+	303,
 	304,
 	305,
 	306,
@@ -3083,10 +3207,12 @@ static const size_t unicode_starting_indextab[]={
 	395,
 	396,
 	397,
+	431,
 	432,
 	433,
 	434,
 	444,
+	463,
 	464,
 	465,
 	466,
@@ -3098,9 +3224,12 @@ static const size_t unicode_starting_indextab[]={
 	472,
 	473,
 	474,
+	479,
 	480,
 	481,
 	482,
+	484,
+	487,
 	488,
 	489,
 	492,
@@ -3354,6 +3483,9 @@ static const size_t unicode_starting_indextab[]={
 	745,
 	746,
 	747,
+	748,
+	749,
+	750,
 	760,
 	761,
 	762,
@@ -3377,6 +3509,22 @@ static const size_t unicode_starting_indextab[]={
 	785,
 	786,
 	787,
+	788,
+	789,
+	790,
+	791,
+	792,
+	793,
+	794,
+	795,
+	796,
+	797,
+	798,
+	799,
+	800,
+	801,
+	802,
+	803,
 	3584,
 	3585
 };
@@ -3389,12 +3537,12 @@ static const char32_t unicode_starting_pagetab[]={
 	38,
 	41,
 	48,
-	66,
-	73,
-	83,
-	102,
-	132,
-	162,
+	65,
+	72,
+	82,
+	101,
+	131,
+	161,
 	187,
 	206,
 	220,
@@ -3407,33 +3555,35 @@ static const char32_t unicode_starting_pagetab[]={
 	259,
 	264,
 	275,
-	284,
-	296,
-	304,
-	309,
-	329,
-	342,
-	343,
-	359,
-	370,
+	283,
+	295,
+	303,
+	308,
+	328,
+	340,
+	341,
+	357,
+	368,
+	380,
+	381,
 	382,
-	383,
-	384,
+	385,
+	386,
 	387,
 	388,
 	389,
 	390,
 	391,
-	392,
-	393,
-	396,
-	401,
+	394,
+	398,
+	414,
 	417,
-	420,
-	422,
-	441,
-	447,
+	419,
+	438,
+	445,
+	451,
 	453,
+	454,
 	455,
 	456,
 	457,
@@ -3458,8 +3608,8 @@ static const char32_t unicode_starting_pagetab[]={
 	476,
 	477,
 	478,
-	479,
 	480,
+	481,
 	482,
 	483,
 	484,
@@ -3545,11 +3695,9 @@ static const char32_t unicode_starting_pagetab[]={
 	564,
 	565,
 	566,
-	567,
-	568,
-	571,
-	572,
-	575,
+	569,
+	570,
+	573,
 	581,
 	587,
 	598,
@@ -3603,80 +3751,61 @@ static const char32_t unicode_starting_pagetab[]={
 	669,
 	679,
 	680,
-	685,
-	695,
-	712,
-	719,
-	727,
-	731,
-	739,
-	745,
-	748,
-	749,
-	752,
-	766,
-	774,
+	686,
+	696,
+	713,
+	720,
+	728,
+	732,
+	740,
+	746,
+	757,
+	758,
+	764,
+	778,
 	786,
-	795,
-	799,
-	801,
-	805,
-	809,
-	816,
-	821,
+	798,
+	807,
+	811,
+	813,
+	818,
+	823,
 	830,
-	846,
-	850,
-	852,
-	857,
+	835,
+	844,
 	860,
-	863,
+	864,
+	866,
+	871,
 	874,
 	877,
-	884,
-	897,
-	898,
-	901,
-	902,
-	903,
-	904,
-	905,
-	908,
-	909,
-	910,
-	911,
-	912,
+	888,
+	892,
+	893,
+	900,
 	913,
-	915,
-	916,
-	917,
-	918,
-	919,
+	914,
 	920,
-	926,
+	921,
+	922,
+	923,
+	924,
+	927,
+	928,
+	929,
+	930,
 	931,
 	932,
-	940,
-	941,
-	942,
-	943,
-	944,
-	945,
-	946,
+	933,
+	934,
+	935,
+	936,
+	937,
+	938,
+	939,
 	947,
-	948,
-	949,
-	950,
-	951,
 	952,
 	953,
-	954,
-	955,
-	956,
-	957,
-	958,
-	959,
-	960,
 	961,
 	962,
 	963,
@@ -3687,80 +3816,66 @@ static const char32_t unicode_starting_pagetab[]={
 	968,
 	969,
 	970,
+	971,
 	972,
+	973,
+	974,
+	975,
 	976,
 	977,
+	978,
+	979,
+	980,
+	981,
+	982,
 	983,
 	984,
+	985,
+	986,
+	987,
+	988,
+	989,
+	990,
+	991,
 	994,
 	996,
-	998,
-	1008,
-	1018,
-	1020,
-	1022,
-	1023,
+	1003,
+	1004,
+	1010,
+	1013,
+	1014,
 	1024,
 	1027,
-	1032,
-	1036,
-	1038,
-	1040,
-	1043,
-	1044,
-	1045,
+	1029,
+	1039,
+	1049,
+	1051,
+	1053,
+	1054,
+	1055,
+	1058,
+	1060,
+	1067,
+	1071,
+	1074,
+	1075,
 	1079,
+	1081,
+	1084,
 	1085,
-	1087,
-	1093,
-	1094,
-	1095,
-	1096,
-	1099,
-	1102,
-	1108,
-	1111,
+	1086,
 	1120,
-	1123,
-	1124,
-	1125,
 	1126,
-	1127,
 	1128,
-	1129,
-	1130,
-	1131,
-	1132,
-	1133,
 	1134,
 	1135,
 	1136,
 	1137,
-	1138,
-	1139,
 	1140,
-	1141,
-	1142,
-	1143,
 	1144,
-	1145,
-	1146,
-	1147,
-	1148,
-	1149,
 	1150,
 	1151,
-	1152,
-	1153,
-	1154,
-	1155,
-	1156,
-	1157,
-	1158,
-	1159,
 	1160,
-	1161,
-	1162,
 	1163,
 	1164,
 	1165,
@@ -3905,7 +4020,9 @@ static const char32_t unicode_starting_pagetab[]={
 	1304,
 	1305,
 	1306,
+	1307,
 	1308,
+	1309,
 	1310,
 	1311,
 	1312,
@@ -3928,6 +4045,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1329,
 	1330,
 	1331,
+	1332,
 	1333,
 	1334,
 	1335,
@@ -3942,9 +4060,7 @@ static const char32_t unicode_starting_pagetab[]={
 	1344,
 	1345,
 	1346,
-	1347,
 	1348,
-	1349,
 	1350,
 	1351,
 	1352,
@@ -3967,7 +4083,6 @@ static const char32_t unicode_starting_pagetab[]={
 	1369,
 	1370,
 	1371,
-	1372,
 	1373,
 	1374,
 	1375,
@@ -3981,6 +4096,65 @@ static const char32_t unicode_starting_pagetab[]={
 	1383,
 	1384,
 	1385,
-	1387
+	1386,
+	1387,
+	1388,
+	1389,
+	1390,
+	1391,
+	1392,
+	1393,
+	1394,
+	1395,
+	1396,
+	1397,
+	1398,
+	1399,
+	1400,
+	1401,
+	1403,
+	1404,
+	1405,
+	1406,
+	1407,
+	1408,
+	1409,
+	1410,
+	1411,
+	1412,
+	1413,
+	1414,
+	1415,
+	1416,
+	1417,
+	1418,
+	1419,
+	1420,
+	1421,
+	1422,
+	1423,
+	1424,
+	1425,
+	1426,
+	1427,
+	1428,
+	1430,
+	1431,
+	1432,
+	1433,
+	1434,
+	1435,
+	1436,
+	1437,
+	1438,
+	1439,
+	1440,
+	1441,
+	1442,
+	1443,
+	1444,
+	1445,
+	1446,
+	1448
 };
 
